@@ -7,7 +7,7 @@ knitr::opts_chunk$set(
 
 ## ----setup--------------------------------------------------------------------
 library(Rgof)
-Bsim = c(100, 200) #Number of Simulation Runs
+Bsim = c(100, 100) #Number of Simulation Runs
 
 ## -----------------------------------------------------------------------------
 set.seed(123)
@@ -16,7 +16,8 @@ set.seed(123)
 vals=0:20 #possible values of random variable
 pnull=function()  pbinom(0:20, 20, 0.5)  # cumulative distribution function (cdf)
 rnull = function() table(c(0:20, rbinom(1000, 20, 0.5)))-1 
-# generate data under the null hypothesis, make sure that vector of counts has same length as vals, possibly 0.
+# generate data under the null hypothesis, make sure that vector of counts has 
+#same length as vals, possibly 0.
 
 ## -----------------------------------------------------------------------------
 x = rnull()
@@ -34,9 +35,9 @@ gof_test(x, vals, pnull, rnull, B=1000, doMethod = "all")$p.value
 gof_test_adjusted_pvalue(x, vals, pnull, rnull, B=c(1000, 500))
 
 ## ----r1, eval=FALSE-----------------------------------------------------------
-#  rnull = function() table(c(0:20, rbinom(rpois(1, 650), 20, 0.5)))-1
-#  x = rnull()
-#  gof_test(x, vals, pnull, rnull, rate=650, B=1000)$p.value
+# rnull = function() table(c(0:20, rbinom(rpois(1, 650), 20, 0.5)))-1
+# x = rnull()
+# gof_test(x, vals, pnull, rnull, rate=650, B=1000)$p.value
 
 ## -----------------------------------------------------------------------------
 vals=0:20
@@ -67,7 +68,7 @@ rnull = function() {
 }
 x = rnull()
 bins = 0:40/20
-vals = (bins[-1]+bins[-21])/2
+vals = (bins[-1]+bins[-21])/2 #use bin midpoints as values
 pnull = function() {
    bins = 1:40/20
    pexp(bins, 1)/pexp(2, 1)
@@ -137,7 +138,7 @@ pnull = function() pbinom(0:10, 10, 0.5)
 rnull =function () table(c(0:10, rbinom(100, 10, 0.5)))-1
 ralt =function (p=0.5) table(c(0:10, rbinom(100, 10, p)))-1
 P=gof_power(pnull, vals, rnull, ralt, 
-  param_alt=seq(0.5, 0.6, 0.02),  B=Bsim, nbins=c(11, 5))
+  param_alt=seq(0.5, 0.6, 0.02), B=Bsim, nbins=c(11, 5))
 plot_power(P, "p", Smooth=FALSE)
 
 ## -----------------------------------------------------------------------------
@@ -184,8 +185,8 @@ gof_power(pnull, NA, rnull, ralt, c(2, 50), phat=phat,
           Range=c(-5,5), TSextra=TSextra, B=Bsim, maxProcessor=2)
 
 ## -----------------------------------------------------------------------------
-newTScont = function(x, Fx) {
-   Fx=sort(Fx)
+newTScont = function(x, pnull, param) {
+   Fx=sort(pnull(x))
    n=length(x)
    out = sum(abs( (2*1:n-1)/2/n-Fx ))
    names(out) = "CvM alt"
@@ -205,36 +206,40 @@ ralt = function(slope=0) {
 }
 
 ## -----------------------------------------------------------------------------
-gof_power(pnull, NA, rnull, ralt, TS=newTScont, param_alt=round(seq(0, 0.5, length=5), 3), Range=c(0,1), B=Bsim)
+gof_power(pnull, NA, rnull, ralt, TS=newTScont, param_alt=round(seq(0, 0.5, length=3), 3), Range=c(0,1), B=Bsim)
 
 ## -----------------------------------------------------------------------------
-vals=1:50/51
-pnull = function() (1:50)/50
-rnull = function() c(rmultinom(1, 500, rep(1/50,50)))
-x = rnull()
-gof_test(x, vals, pnull, rnull, TS=newTSdisc)
+vals=0:10
+pnull = function(p) pbinom(0:10, 10, p) 
+rnull = function(p) table(c(0:10,rbinom(10000, 10, p)))-1
+phat=function(x) sum(0:10*x)/100000
+x = rnull(0.5)
+gof_test(x, vals, pnull, rnull, phat=phat, TS=Rgof::newTSdisc)
 
-## -----------------------------------------------------------------------------
-ralt = function(slope=0) {
-    if(slope==0) p=rep(1/50, 50)
-    else p=diff(slope * (0:50/50)^2 + (1 - slope) * 0:50/50)  
-  c(rmultinom(1, 500, p))
+## ----powerdiscnew-------------------------------------------------------------
+ralt = function(tau=0) {
+   x=rbinom(5000, 10, 0.5-tau)
+   y=rbinom(5000, 10, 0.5+tau) 
+   table(c(0:10,x,y))-1
 }
-gof_power(pnull, vals, rnull, ralt, TS=newTSdisc, param_alt=round(seq(0, 0.5, length=5), 3), B=Bsim)
+gof_power(pnull, vals, rnull, ralt,
+    TS=Rgof::newTSdisc, phat=phat, 
+    param_alt=round(seq(0, 0.05, length=3), 3),
+    B=Bsim, maxProcessors = 1)
 
 ## ----eval=FALSE---------------------------------------------------------------
-#  pnull=function(x) punif(x)
-#  rnull=function() runif(250)
-#  pvals=matrix(0,1000,16)
-#  for(i in 1:1000) pvals[i, ]=Rgof::gof_test(rnull(), NA, pnull, rnull,B=1000)$p.values
+# pnull=function(x) punif(x)
+# rnull=function() runif(250)
+# pvals=matrix(0,1000,16)
+# for(i in 1:1000) pvals[i, ]=Rgof::gof_test(rnull(), NA, pnull, rnull,B=1000)$p.values
 
 ## ----eval=FALSE---------------------------------------------------------------
-#  colnames(pvals)=names(Rgof::gof_test(rnull(), NA, pnull, rnull,B=10)$p.values)
-#  p1=apply(pvals[, c("W", "ZC", "AD", "ES-s-P" )], 1, min)
-#  p2=apply(pvals[, c("KS", "K", "AD", "CvM")], 1, min)
+# colnames(pvals)=names(Rgof::gof_test(rnull(), NA, pnull, rnull,B=10)$p.values)
+# p1=apply(pvals[, c("W", "ZC", "AD", "ES-s-P" )], 1, min)
+# p2=apply(pvals[, c("KS", "K", "AD", "CvM")], 1, min)
 
 ## -----------------------------------------------------------------------------
-tmp=readRDS("../inst/extdata/pvaluecdf.rds")
+tmp=Rgof::pvaluecdf
 Tests=factor(c(rep("Identical Tests", nrow(tmp)),
         rep("Correlated Selection", nrow(tmp)),
         rep("Best Selection", nrow(tmp)),
@@ -261,3 +266,38 @@ ralt=function(m=0) {x=rt(2000,df)+m;x=x[abs(x)<3];sort(x[1:1000])}
 set.seed(111)
 Rgof::gof_power(pnull, NA, rnull, ralt, w=w, param_alt = c(0,0.2), Range=c(-3,3),B=Bsim)
 
+## -----------------------------------------------------------------------------
+chitest=function(x, pnull, param, TSextra) {
+    nbins=TSextra$nbins #number of bins
+    bins=seq(min(x)-1e-10, max(x)+1e-10, length=nbins+1)
+    O=hist(x, bins, plot=FALSE)$counts #bin counts
+    if(param[1]!=-99) { #with parameter estimation
+        E=length(x)*diff(pnull(bins, param)) #expected counts
+        chi=sum((O-E)^2/E) #Pearson's chi square
+        pval=1-pchisq(chi, nbins-1-length(param)) #p value
+    }
+    else {
+      E=length(x)*diff(pnull(bins))
+      chi=sum((O-E)^2/E)
+      pval=1-pchisq(chi,nbins-1)
+    }  
+    out=ifelse(TSextra$statistic, chi, pval)
+    names(out)="ChiSquare"
+    out
+}
+
+## -----------------------------------------------------------------------------
+TSextra=list(nbins=5, statistic=FALSE)
+pwr=Rgof::run.studies(chitest, "uniform.linear", TSextra=TSextra, With.p.value=TRUE)
+Rgof::plot_power(pwr, "Slope")
+
+## ----eval=FALSE, message=FALSE------------------------------------------------
+# Rgof::run.studies(chitest, TSextra=TSextra, With.p.value=TRUE)
+
+## ----eval=FALSE, message=FALSE------------------------------------------------
+# Rgof::run.studies(TRUE, # continuous data/model
+#                   study="uniform.linear",
+#                   param_alt=c(0.1, 0.2),
+#                   nsample=2000,
+#                   alpha=0.01)
+
