@@ -1,21 +1,20 @@
 #include <Rcpp.h>
+#include "Cpporder.h"
 using namespace Rcpp;
 
 //' Find test statistics for continuous data
 //' 
 //' @param x A numeric vector.
-//' @param Fx numeric vector of cdf probabilities.
-//' @param param parameters for pnull
+//' @param pnull cdf.
+//' @param param parameters for pnull  in case of parameter estimation.
 //' @param qnull An R function, the quantile function under the null hypothesis.
-//' @keywords internal
 //' @return A numeric vector with test statistics
 // [[Rcpp::export]]
 Rcpp::NumericVector TS_cont(
         Rcpp::NumericVector x, 
-        Rcpp::NumericVector Fx,
+        Rcpp::Function pnull,
         Rcpp::NumericVector param, 
         Rcpp::Function qnull) {
-  
   Rcpp::CharacterVector methods=Rcpp::CharacterVector::create("KS", "K", "AD", "CvM", "W", "ZA", "ZK", "ZC", "Wassp1");
   int const nummethods=methods.size();
   int n=x.size(), i;
@@ -23,10 +22,22 @@ Rcpp::NumericVector TS_cont(
   double m, tmp, tmp1;
   TS.names() =  methods;
 
+  /* some setup */
+  Rcpp::Environment base("package:base");
+  Rcpp::Function formals_r = base["formals"];
+  Rcpp::List respnull = formals_r(Rcpp::_["fun"]=pnull);
+  NumericVector Fx(n);
+  if(respnull.size()==1) Fx = pnull(x);
+  else Fx = pnull(x, param);
+  Rcpp::List resqnull = formals_r(Rcpp::_["fun"]=qnull);
+  NumericVector qtmp(n);
+  if(resqnull.size()==1) qtmp = qnull(0.5);
+  else qtmp = qnull(0.5, 0);
+  
   /*  sort data */
 
-  std::sort(x.begin(), x.end());
-  std::sort(Fx.begin(), Fx.end());
+  x = Cpporder(x, x);
+  Fx = Cpporder(Fx, Fx);
 
   /*  Kolmogorov-Smirnov and Kuiper*/
 
@@ -34,16 +45,16 @@ Rcpp::NumericVector TS_cont(
     double mx=0.0, Mx=0.0;
     for(i=0;i<n;++i) {
       tmp = Fx[i]-double(i)/n;
-      if(tmp<0 && std::abs(tmp)>std::abs(mx)) mx=std::abs(tmp);
-      if(tmp>0 && std::abs(tmp)>std::abs(Mx)) Mx=std::abs(tmp);
+      if(tmp<mx) mx=tmp;
+      if(tmp>Mx) Mx=tmp;
       tmp = double(i+1)/n-Fx[i];
-      if(tmp<0 && std::abs(tmp)>std::abs(mx)) mx=std::abs(tmp);
-      if(tmp>0 && std::abs(tmp)>std::abs(Mx)) Mx=std::abs(tmp);      
+      if(tmp<mx) mx=tmp;
+      if(tmp>Mx) Mx=tmp;
     }
     if(std::abs(mx)>std::abs(Mx)) TS(0)=std::abs(mx);
     else TS(0)=std::abs(Mx);
     TS(1) = std::abs(mx)+std::abs(Mx);
- 
+
   /* Anderson-Darling */
 
  
@@ -53,7 +64,7 @@ Rcpp::NumericVector TS_cont(
     }
     TS(2)=-n-tmp/n;
   
-  /* Cramer-von Mises and/or Wilson*/
+  /* Cramer-von Mises and/or Watson*/
 
     tmp=0.0;
     tmp1=0.0;
@@ -70,30 +81,26 @@ Rcpp::NumericVector TS_cont(
     TS(6) = 0.0;
     TS(7) = 0.0;
     for(i=0; i<n; ++i) {
-      m = i+0.5;
-      TS(5) = TS(5) - log(Fx[i])/(n-m) - log(1-Fx[i])/m;
-      tmp =  m*log(m/n/Fx[i]) + (n-m)*log((n-m)/n/(1-Fx[i]));
-      if(tmp>TS(6)) TS(6)=tmp;
-      tmp = log( (1/Fx[i]-1)/((n-0.5)/(i+0.25)-1) );
-      TS(7) = TS(7) + tmp*tmp;
+      if(Fx[i]<1) {
+        m = i+0.5;
+        TS(5) = TS(5) - log(Fx[i])/(n-m) - log(1-Fx[i])/m;
+        tmp =  m*log(m/n/Fx[i]) + (n-m)*log((n-m)/n/(1-Fx[i]));
+        if(tmp>TS(6)) TS(6)=tmp;
+        tmp = log( (1/Fx[i]-1)/((n-0.5)/(i+0.25)-1) );
+        TS(7) = TS(7) + tmp*tmp;
+      }  
     }
   
-  Rcpp::Environment base("package:base");
-  Rcpp::Function formals_r = base["formals"];
-  Rcpp::List res = formals_r(Rcpp::_["fun"]=qnull);
-  NumericVector qtmp(n);
-  if(res.size()==1) qtmp = qnull(0.5);
-  else qtmp = qnull(0.5, 0);
     NumericVector a1(n+1),a2(n);
     for(i=0;i<=n;++i) {
       a1[i]=double(i)/n;
       if(a1[i]<1e-10) a1[i]=1e-10;
       if(a1[i]>1-1e-10) a1[i]=1-1e-10;
     }  
-    if(res.size()==1) b1=qnull(a1);
+    if(resqnull.size()==1) b1=qnull(a1);
     else b1=qnull(a1, param);
     for(i=0;i<n;++i) a2[i]=(2.0*i+1.0)/2.0/n;
-    if(res.size()==1) b2=qnull(a2);
+    if(resqnull.size()==1) b2=qnull(a2);
     else b2=qnull(a2, param);
     
     TS(8) = 0.0;
